﻿using Syncfusion.UI.Xaml.Charts;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Collections.Specialized;
using System.ComponentModel;
using System.Diagnostics;
using System.Globalization;
using System.Linq;
using System.Text;
using System.Threading;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.Collections;
using System.IO;
using Syncfusion.Pdf;
using Syncfusion.Pdf.Graphics;
using Microsoft.Win32;

namespace Sample1
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
        }

        public class Person
        {
            public string Name { get; set; }
            public double Height { get; set; }
        }
        public class ViewModel
        {
            public List<Person> Data { get; set; }

            public ViewModel()
            {
                Data = new List<Person>()
            {
                new Person { Name = "David", Height = 180 },
                new Person { Name = "Michael", Height = 170 },
                new Person { Name = "Steve", Height = 160 },
                new Person { Name = "Joel", Height = 182 }
            };
            }
        }
        public SfChart GetForPDF()
        {
            SfChart chart = new SfChart();
            chart.Background = new SolidColorBrush(Colors.White);
            CategoryAxis primaryAxis = new CategoryAxis
            {
                Header = "Name"
            };
            chart.PrimaryAxis = primaryAxis;
            NumericalAxis secondaryAxis = new NumericalAxis
            {
                Header = "Height(in cm)"
            };
            chart.SecondaryAxis = secondaryAxis;
            ColumnSeries series = new ColumnSeries
            {
                ItemsSource = (new ViewModel()).Data,
                XBindingPath = "Name",
                YBindingPath = "Height"
            };
            chart.Series.Add(series);
            this.DataContext = chart;

            //To Render the Chart UI without showing the window 
            chart.Measure(new Size(double.PositiveInfinity, double.PositiveInfinity));
            chart.Arrange(new Rect(new Point(0, 0), chart.DesiredSize));

            return chart;
        }
        public PdfDocument pdfDoc;
        private void ChartToPDF()
        {
            MemoryStream outStream = new MemoryStream();
            var chart = GetForPDF();
            chart.Save(outStream, new BmpBitmapEncoder());
            PdfPage page = pdfDoc.Pages.Add();
            PdfBitmap img = new PdfBitmap(outStream);
            page.Graphics.DrawImage(img, 0, 0, 500, 250);
            outStream.Close();
        }

        private void SavePDF(string pdfFile)
        {
            SaveFileDialog dialog = new SaveFileDialog();
            dialog.Filter = "PDF document (*.pdf)|*.pdf";
            Boolean? result = dialog.ShowDialog();
            string fileName = dialog.FileName;

            if ((bool)result)
            {
                pdfDoc.Save(fileName);
            }
        }

        private void btnCreate_Click(object sender, RoutedEventArgs e)
        {
            pdfDoc = new PdfDocument();
            ChartToPDF();
            SavePDF("chartpdf.pdf");
        }
    }

    public class Model
    {
        public double XValue { get; set; }
        public double YValue { get; set; }
    }

    public class ViewModel
    {
        public ViewModel()
        {
            GenerateData();           
        }

        public void GenerateData()
        {
            Data = new ObservableCollection<Model>();
            Random rd = new Random();
            for (int i = 0; i < 6; i++)
            {
                Data.Add(new Model()
                {
                    XValue = i,
                    YValue = rd.Next(0, 50)
                });
            }
        }

        private ObservableCollection<Model> data;

        public ObservableCollection<Model> Data
        {
            get { return data; }
            set { data = value;  }
        }

        
       
    }
    
}
